@@ -9,9 +9,9 @@ typedef struct {
 
 static const WidthRange width_table[] = {
 //    { 0x0, 0x1f, -1 },
-    { 0x20, 0x7e, 1 },
+//    { 0x20, 0x7e, 1 },
 //    { 0x7f, 0x9f, -1 },
-    { 0xa0, 0xa0, 1 },
+//    { 0xa0, 0xa0, 1 },
     { 0xa1, 0xa1, 2 },
     { 0xa2, 0xa3, 1 },
     { 0xa4, 0xa4, 2 },
@@ -1309,7 +1309,7 @@ static const WidthRange width_table[] = {
     { 0xf0000, 0xffffd, 2 },
     { 0xffffe, 0xfffff, 1 },
     { 0x100000, 0x10fffd, 2 },
-    { 0x10fffe, 0x10ffff, 1 },
+//    { 0x10fffe, 0x10ffff, 1 },
 };
 
 static const int width_table_len = sizeof(width_table) / sizeof(width_table[0]);
